@@ -4,7 +4,8 @@ time_series_dataset
 
 import abc
 from torch.utils.data import Dataset
-from .min_max_scaler import MinMaxScaler
+# from .three_d_min_max_scaler import ThreeDMinMaxScaler as Scaler
+from .min_max_scaler import MinMaxScaler as Scaler
 
 class TimeSeriesDataset(Dataset):
     """
@@ -12,41 +13,41 @@ class TimeSeriesDataset(Dataset):
 
     :param _x: input predictor
     :param _y: output predictor
+    :param labels: predictors labels
     """
+    # pylint: disable=invalid-name
     def __init__(self, _x, _y, labels):
         super().__init__()
         self.labels = labels
-        # Normalize x
-        self.scaler_x = MinMaxScaler()
-        self._x = self.scaler_x.fit_transform(_x)
-        # Normalize y
-        self.scaler_y = MinMaxScaler()
-        self._y = self.scaler_y.fit_transform(_y)
+        self.x = _x
+        self.y = _y
 
     def __getitem__(self, idx):
-        return (self._x[idx], self._y[idx])
+        return (self.x[idx], self.y[idx])
 
     def __len__(self):
-        return self._x.shape[0]
+        return self.x.shape[0]
 
     def get_x_shape(self):
         """get_x_shape
 
         :returns: input predictor shape
         """
-        return self._x.shape
+        return self.x.shape
 
     def get_y_shape(self):
         """get_y_shape
 
         :returns: output predictor shape
         """
-        return self._y.shape
+        return self.y.shape
 
     @abc.abstractmethod
     def make_future_dataframe(self, *args, **kwargs):
         """make_future_dataframe
 
-        :param *args: variable length unnamed args list
-        :param **kwargs: variable length named args list
+        Parameters
+        ----------
+        *args: variable length unnamed args list
+        **kwargs: variable length named args list
         """
